@@ -94,4 +94,4 @@ class MultiPage:
 
                 st.session_state[namespace].update(variables)
 
-            self.__apps[page].func()
\ No newline at end of file
+            self.__apps[page].func(st)
\ No newline at end of file
